diff --git a/buildnum.properties b/buildnum.properties
index 18863df..af8d31e 100644
--- a/buildnum.properties
+++ b/buildnum.properties
@@ -1,3 +1,3 @@
#ANT Task: ch.oscg.jreleaseinfo.BuildNumberHandler
-#Thu May 05 12:13:40 PDT 2005
-build.num.last=26
+#Wed May 11 02:01:54 PDT 2005
+build.num.last=27
diff --git a/lib/commons-httpclient-3.0-rc1.jar b/lib/commons-httpclient-3.0-rc1.jar
deleted file mode 100644
index 124a3d9..0000000
Binary files a/lib/commons-httpclient-3.0-rc1.jar and /dev/null differ
diff --git a/lib/commons-httpclient-3.0-rc2.jar b/lib/commons-httpclient-3.0-rc2.jar
new file mode 100644
index 0000000..bea0a98
Binary files /dev/null and b/lib/commons-httpclient-3.0-rc2.jar differ
diff --git a/lib/delicious-1.5.jar b/lib/delicious-1.5.jar
deleted file mode 100644
index 3b8e1a9..0000000
Binary files a/lib/delicious-1.5.jar and /dev/null differ
diff --git a/lib/delicious-1.6.jar b/lib/delicious-1.6.jar
new file mode 100644
index 0000000..c474405
Binary files /dev/null and b/lib/delicious-1.6.jar differ
diff --git a/mobibot.iml b/mobibot.iml
index 83fec44..5cd6034 100644
--- a/mobibot.iml
+++ b/mobibot.iml
@@ -135,24 +135,6 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
@@ -162,6 +144,24 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/mobibot.ipr b/mobibot.ipr
index 9d96bb8..257fe13 100644
--- a/mobibot.ipr
+++ b/mobibot.ipr
@@ -1,5 +1,5 @@
-
+
diff --git a/mobibot.iws b/mobibot.iws
index c3f95ab..55485c3 100644
--- a/mobibot.iws
+++ b/mobibot.iws
@@ -1,5 +1,5 @@
-
+
@@ -71,7 +71,7 @@
-
+
@@ -115,14 +115,14 @@
-
+
-
+
@@ -131,7 +131,7 @@
-
+
@@ -194,18 +194,18 @@
-
-
+
+
-
-
-
+
+
+
@@ -268,6 +268,13 @@
+
+
+
+
+
+
+
@@ -278,20 +285,6 @@
-
-
-
-
-
-
-
-
-
-
-
-
@@ -306,13 +299,6 @@
-
-
-
-
-
-
-
@@ -320,20 +306,34 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
-
-
+
@@ -394,7 +394,7 @@
-
+
@@ -402,7 +402,7 @@
-
+
@@ -539,14 +539,14 @@
-
+
-
+
@@ -555,7 +555,7 @@
-
+
diff --git a/src/net/thauvin/erik/mobibot/ReleaseInfo.java b/src/net/thauvin/erik/mobibot/ReleaseInfo.java
index 3d00934..1ef639f 100644
--- a/src/net/thauvin/erik/mobibot/ReleaseInfo.java
+++ b/src/net/thauvin/erik/mobibot/ReleaseInfo.java
@@ -1,5 +1,5 @@
/* Created by JReleaseInfo AntTask from Open Source Competence Group */
-/* Creation date Thu May 05 12:13:41 PDT 2005 */
+/* Creation date Wed May 11 02:01:54 PDT 2005 */
package net.thauvin.erik.mobibot;
import java.util.Date;
@@ -12,21 +12,21 @@ import java.util.Date;
public class ReleaseInfo {
- /** buildDate (set during build process to 1115320421004L). */
- private static Date buildDate = new Date(1115320421004L);
+ /** buildDate (set during build process to 1115802114846L). */
+ private static Date buildDate = new Date(1115802114846L);
/**
- * Get buildDate (set during build process to Thu May 05 12:13:41 PDT 2005).
+ * Get buildDate (set during build process to Wed May 11 02:01:54 PDT 2005).
* @return Date buildDate
*/
public static final Date getBuildDate() { return buildDate; }
/**
* Get buildNumber (set during build process to 26).
* @return int buildNumber
*/
- public static final int getBuildNumber() { return 26; }
+ public static final int getBuildNumber() { return 27; }
/** version (set during build process to "0.3"). */
@@ -12,21 +12,21 @@ import java.util.Date;
public static final Date getBuildDate() { return buildDate; }
/**
- * Get buildNumber (set during build process to 26).
+ * Get buildNumber (set during build process to 27).
* @return int buildNumber
*/